Internal_Datalogger but with USB support removed (for MAX40108 Demo board), proof of concept that MAX32625 can be used successfully with VDDB(USB) left unpowered, as long as the USB library is not used.

Dependencies:   max32625pico CmdLine

Revision:
27:b4ac095b83b3
Parent:
26:13cba69d88eb
Child:
28:a9a3a9db592b
--- a/DataLogger_Internal.cpp	Sun Apr 25 02:15:41 2021 -0700
+++ b/DataLogger_Internal.cpp	Sun Apr 25 02:31:08 2021 -0700
@@ -2895,7 +2895,7 @@
 #if USE_DATALOGGER_SPIDeviceRegRead
     // TODO: Datalogger_Trigger = trigger_SPIDeviceRegRead // SPI device register read (configure regaddr, mask value, match value)
     //~ cmdLine.serial().printf("\r\n L$ -- Datalog _______"); // trigger_SPIDeviceRegRead
-    cmdLine.serial().printf("\r\n L$regaddr@dataMask=testValue -- Datalog when SPI read of address matches mask"); // trigger_SPIDeviceRegRead
+    cmdLine.serial().printf("\r\n L$ count=10 base=500ms addr=xxx data=xxx mask=xxx -- Datalog when SPI read of address matches mask"); // trigger_SPIDeviceRegRead
 #endif // USE_DATALOGGER_SPIDeviceRegRead
     //
 #if USE_DATALOGGER_ActionTable // Datalogger_RunActionTable() supported actions
@@ -4109,7 +4109,7 @@
                     }
                     break;
 #if USE_DATALOGGER_SPIDeviceRegRead
                 // L$regaddr@dataMask=testValue -- Datalog when SPI read of address matches mask
                 case '$':
                     {
                         // TODO: scan cmdLine for regAddr, dataMask, testValue
@@ -4109,7 +4109,7 @@
                     break;
 #if USE_DATALOGGER_SPIDeviceRegRead
-                // L$regaddr@dataMask=testValue -- Datalog when SPI read of address matches mask
+                // L$ count=10 base=500ms addr=xxx data=xxx mask=xxx -- Datalog when SPI read of address matches mask
                 case '$':
                     {